%define		configver	10
%define		extravbit	%{nil}

Summary:	The Linux Kernel, Version 2.6.x
Name:		kernel26
Version:	2.6.3
Release:	1.5.2
Copyright:	GPL
Group:		System Environment/Kernel
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root
Requires:	initscripts
PreReq:		mkinitrd >= 3.5.7, modutils >= 2.4.26
Source000:	ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{version}%{extravbit}.tar.bz2
Provides:	kernel = %{version}

# Configs.
Source100:	kernel-config-2.6-i386-gd-%{configver}.config

# Patches
Patch100:	kernel-2.6.2-exec-shield-G9-gd-1.diff

%description
The kernel package contains the Linux kernel (vmlinuz), the core of your
EnGarde Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%files
  %defattr(-,root,root)
  /boot/vmlinux-%{version}-%{release}
  /boot/vmlinuz-%{version}-%{release}
  /boot/System.map-%{version}-%{release}
  %dir /lib/modules/%{version}-%{release}
  /lib/modules/%{version}-%{release}/*

%package source
Requires:	kernel-headers = %{version}
Summary:	The source code for the Linux kernel.
Group:		Development/System

%description source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned
to your particular hardware, if you are so inclined (and you know what
you're doing).

%files source
  %defattr(-,root,root)
  /usr/src/linux-%{version}/COPYING
  /usr/src/linux-%{version}/CREDITS
  /usr/src/linux-%{version}/Documentation
  /usr/src/linux-%{version}/MAINTAINERS
  /usr/src/linux-%{version}/Makefile
  /usr/src/linux-%{version}/README
  /usr/src/linux-%{version}/REPORTING-BUGS
  /usr/src/linux-%{version}/arch
  /usr/src/linux-%{version}/configs
  /usr/src/linux-%{version}/crypto
  /usr/src/linux-%{version}/drivers
  /usr/src/linux-%{version}/fs
  /usr/src/linux-%{version}/init
  /usr/src/linux-%{version}/ipc
  /usr/src/linux-%{version}/kernel
  /usr/src/linux-%{version}/lib
  /usr/src/linux-%{version}/mm
  /usr/src/linux-%{version}/net
  /usr/src/linux-%{version}/scripts
  /usr/src/linux-%{version}/security
  /usr/src/linux-%{version}/sound
  /usr/src/linux-%{version}/usr

%package headers
Summary:	Header files for the Linux kernel.
Group:		Development/System

%description headers
Kernel-headers includes the C header files for the Linux kernel.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
kernel.

%files headers
  %defattr(-,root,root)
  %dir /usr/src/linux-%{version}
  /usr/src/linux-%{version}/configs
  /usr/src/linux-%{version}/include
  /boot/kernel.h-%{version}

%prep
%setup -q -n linux-%{version}%{extravbit}
%patch100 -p1

  # Copy in configs
  mkdir configs
  cp -fv %{SOURCE100} configs

  # Remove patch fodder.
  # find . -name "*.orig" -exec rm -fv {} \;
  # find . -name "*~" -exec rm -fv {} \;

%build
  if [ -x /usr/bin/getconf ] ; then
    NRPROC=$(/usr/bin/getconf _NPROCESSORS_ONLN)
    if [ $NRPROC -eq 0 ] ; then NRPROC=1; fi
  else
    NRPROC=1
  fi

  NRPROC=$(expr $NRPROC \* 2)

  BuildKernel() {
    if [ -n "$1" ] ; then
      Config=%{_target_cpu}-$1
      KernelVer=%{version}-%{release}-$1
    else
      Config=%{_target_cpu}
      KernelVer=%{version}-%{release}
    fi

    # Remove *.orig files.
    find . -name \*.orig -exec rm {} \; && make mrproper

    # Little ditty.
    echo "- ------> kernel-%{version}-$Config-%{configver}.confg <----------"

    # Only append $1 if we have one.
    if [ -n "$1" ] ; then
      perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}-$1/" Makefile
    else
      perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}/" Makefile
    fi

    # Make the kernel
    make mrproper
    cp configs/kernel-config-2.6-$Config-gd-%{configver}.config .config
    make oldconfig
    make -j $NRPROC

    # Install the kernel
    mkdir -p $RPM_BUILD_ROOT/boot
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    cp arch/i386/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer

    # preserve .ver files
    find include/linux/modules -size 0 | while read file ; do \
        echo > $file
    done

    # Only append $1 if we have one.
    if [ -n "$1" ] ; then
        make INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install \
                KERNELRELEASE=%{version}-%{release}-$1
    else
        make INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install \
                KERNELRELEASE=%{version}-%{release}
    fi

    # copy config file back in case changes were made
    cp .config configs/kernel-config-2.6-$Config-%{configver}.config-NEW

    # Check our module dependencies.
    depmod -ae -b $RPM_BUILD_ROOT \
               -F $RPM_BUILD_ROOT/boot/System.map-$KernelVer $KernelVer
  }

  SaveHeaders() {
    mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{version}/include/linux
    if [ -n "$1" ] ; then
      install -m 644 include/linux/autoconf.h \
         $RPM_BUILD_ROOT/usr/src/linux-%{version}/include/linux/autoconf-$1.h
      install -m 644 include/linux/version.h \
         $RPM_BUILD_ROOT/usr/src/linux-%{version}/include/linux/version-$1.h
    else
      install -m 644 include/linux/autoconf.h \
         $RPM_BUILD_ROOT/usr/src/linux-%{version}/include/linux/autoconf.h
      install -m 644 include/linux/version.h \
         $RPM_BUILD_ROOT/usr/src/linux-%{version}/include/linux/version.h
    fi
  }

  [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

  # Build our standard kernel.
  BuildKernel 
  SaveHeaders 

%pre
  /sbin/modprobe loop > /dev/null 2>&1
  exit 0

################################################################################
%install
  mkdir -p $RPM_BUILD_ROOT/{boot,sbin}
  mkdir -p $RPM_BUILD_ROOT/usr/include

  ln -sf ../src/linux/include/linux $RPM_BUILD_ROOT/usr/include/linux
  mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{version}

  > $RPM_BUILD_ROOT/boot/kernel.h-%{version}

  make mrproper
  mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{version}
  tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{version}

################################################################################
%post
  cd /boot
  ln -sf vmlinuz-%{version}-%{release} vmlinuz26 || :
  ln -sf System.map-%{version}-%{release} System.map26 || :

  mkinitrd -f initrd-%{version}-%{release} %{version}-%{release} || :
  ln -sf initrd-%{version}-%{release} initrd26 || :

  # Generate modprobe.conf if it does not exist.
  if [ ! -f /etc/modprobe.conf ]
  then
    generate-modprobe.conf > /etc/modprobe.conf
  fi

  # Add a 'standard26' image if one does not already exist.
  ROOT=$(grep root= /etc/lilo.conf | head -1 | sed 's|^ *root=||g')
  grep -q "label=standard26" /etc/lilo.conf; DOIT=$?

  if [ $DOIT != 0 -a -e $ROOT -a -L /boot/vmlinuz26 -a -L /boot/initrd26 ]
  then
    cat <<EOF >>/etc/lilo.conf

image=/boot/vmlinuz26
   initrd=/boot/initrd26
   label=standard26
   read-only
   root=$ROOT
EOF
  fi

################################################################################
%clean
  [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

################################################################################
%post headers
  cd /usr/src
  rm -f linux
  ln -snf linux-%{version} linux
  cd /usr/include
  rm -f linux asm
  ln -snf ../src/linux/include/linux linux
  ln -snf ../src/linux/include/asm asm
  cd /boot
  rm -f kernel.h kernel.h-%{version}
  ln -snf /usr/src/linux/include/linux/kernel.h-%{version} kernel.h-%{version}
  exit 0

################################################################################
%post source
  cd /usr/src
  rm -f linux
  ln -snf linux-%{version} linux

################################################################################
%postun headers
  if [ -L /usr/src/linux ]; then
    if [ `ls -l /usr/src/linux | awk '{ print $11 }'` = "linux-%{version}" ]; then
        [ $1 = 0 ] && rm -f /usr/src/linux /usr/include/linux /usr/include/asm /boot/kernel.h /boot/kernel.h-%{version}
    fi
  fi

################################################################################
%postun source
  if [ -L /usr/src/linux ]; then
    if [ `ls -l /usr/src/linux | awk '{ print $11 }'` = "linux-%{version}" ]; then
        [ $1 = 0 ] && rm -f /usr/src/linux
    fi
  fi

################################################################################
%changelog
* Mon Feb 23 2004 Ryan W. Maple <ryan@guardianigital.com>
- Version 2.6.3, Release 1.5.2
  - Upgrade to 2.6.3.
  - Modularize SATA as we have in our 2.4 kernels.
  - Bump configs (9 => 10).

* Wed Feb 04 2004 Ryan W. Maple <ryan@guardianigital.com>
- Version 2.6.2, Release 1.5.1
  - Strip previous changelog and give this package a Thrust release number.
  - Add a non-default 'standard26' image in /etc/lilo.conf
  - Generate modprobe.conf if it does not exist.
